<?php
require_once("../../classes/class.users.php");
require_once("../../classes/class.validation.php");
require_once("../../classes/class.authentication.php");
require_once("../../classes/class.date_processing.php");
require_once("../../classes/class.ui_helpers.php");

require_once("../../classes/school_administration/class.classes.php");
require_once('../../classes/school_administration/class.class_sections.php');

require_once("../../classes/academic_supervision/class.chapters.php");
require_once("../../classes/academic_supervision/class.chapter_topics.php");
require_once("../../classes/academic_supervision/class.student_assignment.php");

require_once("../../classes/school_administration/class.students.php");
require_once("../../classes/school_administration/class.student_details.php");

require_once("../../includes/global_defaults.inc.php");
//1. RECHECK IF THE USER IS VALID //
try
{
    $AuthObject = new ApplicationAuthentication;
    $LoggedUser = new User(0, $AuthObject->CheckValidUser());
}

// THIS CATCH BLOCK BUBBLES THE EXCEPTION TO THE BUILT IN 'Exception' CLASS IF THERE ARE ANY UNCAUGHT ERRORS //
catch (ApplicationAuthException $e)
{
    header('location:unauthorized_login_admin.php');
    exit;
}
catch (Exception $e)
{
    header('location:unauthorized_login_admin.php');
    exit;
}
// END OF 1. //

if ($LoggedUser->HasPermissionForTask(TASK_LIST_STUDENT_ASSIGNMENT) !== true)
{
    header('location:/admin/unauthorized_login_admin.php');
    exit;
}

$HasErrors = false;

$Clean = array();
$Clean['Process'] = 0;

$Clean['StudentID'] = 0;
$Clean['AssignmentID'] = 0;

if (isset($_GET['StudentID']))
{
	$Clean['StudentID'] = (int) $_GET['StudentID'];
}

if (isset($_GET['AssignmentID']))
{
	$Clean['AssignmentID'] = (int) $_GET['AssignmentID'];
}

if ($Clean['StudentID'] <= 0 || $Clean['AssignmentID'] <= 0)
{
    header('location:unauthorized_login_admin.php');
    exit;
}

$StudentAssignmentAnswers = array();
$StudentAssignmentAnswers = StudentAssignment::SearchStudentAssignmentAnswers($Clean['StudentID'], $Clean['AssignmentID']);

if (count($StudentAssignmentAnswers) <= 0)
{
    header('location:unauthorized_login_admin.php');
    exit;
}

try
{
    $StudentDetailObj = new StudentDetail($Clean['StudentID']);
    $StudentAssignmentObj = new StudentAssignment($Clean['AssignmentID']);
}
catch (Exception $e)
{
    header('location:unauthorized_login_admin.php');
    exit;
}

require_once('../html_header.php');
?>
<title>Students Assignment Answers List</title>
<!-- DataTables CSS -->
<link href="/admin/vendor/datatables-plugins/dataTables.bootstrap.css" rel="stylesheet">

<!-- DataTables Responsive CSS -->
<link href="/admin/vendor/datatables-responsive/dataTables.responsive.css" rel="stylesheet">
</head>

<body>

    <div id="wrapper">
        <!-- Navigation -->
        <nav class="navbar navbar-default navbar-static-top" role="navigation" style="margin-bottom: 0">
<?php 
            require_once('../site_header.php');
            require_once('../left_navigation_menu.php');
?>                    
            <!-- /.navbar-static-side -->
        </nav>

        <div id="page-wrapper">
            <div class="row">
                <div class="col-lg-12 text-center">
                    <h2 class="page-header">Assignment Heading: <?php echo $StudentAssignmentObj->GetAssignmentHeading(); ?></h2>
                </div>
                <div class="col-lg-12">
                    <h3 class="page-header">Answers Uploaded By <?php echo $StudentDetailObj->GetFirstName().' '.$StudentDetailObj->GetLastName().' ('.$StudentDetailObj->GetRollNumber().')'; ?></h3>
                </div>
                <!-- /.col-lg-12 -->
            </div>
            <!-- /.row -->
            <div class="row">
                <div class="col-lg-12">
                    <div class="panel panel-default">
                        <!-- /.panel-heading -->
                        <div class="panel-body">
                            <div class="container col-lg-12">
                                
                            <div class="row">
                            <?php
                            //echo '<pre>';
                            //print_r($StudentAssignmentAnswers);exit;
								foreach ($StudentAssignmentAnswers as $FileType => $AnswerList)
								{
								    foreach ($AnswerList as $AssignmentAnswerID => $AnswerDetails)
								    {
    									if ($FileType == 'Image')
    									{
    									    ?>
    									    <div class="col-lg-3 text-center" style="padding: 10px; height: 180px; border-radius: 2%; border: 1px solid black; margin: 15px 10px 0 10px;">
                                                <a target="_blank" href="/site_images/student_assignment_answers/<?php echo $Clean['AssignmentID'].'/'.$AnswerDetails['AnswerImageName']; ?>"style="margin-bottom: 20px; border: solid 2px black;"">
        									    <img src="/site_images/student_assignment_answers/<?php echo $Clean['AssignmentID'].'/'.$AnswerDetails['AnswerImageName']; ?>" style="max-width: 235px; max-height:160px; min-width: 235px; min-height:160px;" ></a>
    									    </div>
    									    <?php
    									}
    									else
    									{
    									    echo '<div class="col-lg-3 text-center" style="padding: 10px; height: 180px; border-radius: 2%; border: 1px solid black; margin: 15px 10px 0 10px;">';
    									    echo '<embed src="/site_images/student_assignment_answers/'.$Clean['AssignmentID'].'/'.$AnswerDetails['AnswerImageName'].'" type="application/pdf" style="max-width: 235px; max-height:160px; min-width: 235px; min-height:160px;" class="responsive" width="100%" height="100%">';
                                            echo '<a target="_blank" href="/site_images/student_assignment_answers/'.$Clean['AssignmentID'].'/'.$AnswerDetails['AnswerImageName'].'"><strong>Download</strong></a>';
                                            echo '</div>';
    									}
								    }
								}
							?>
							</div>
							</div>
                        </div>
                        <!-- /.panel-body -->
                    </div>
                    <!-- /.panel -->
                </div>
                <!-- /.col-lg-12 -->
            </div>
        </div>
        <!-- /#page-wrapper -->

    </div>
    <!-- /#wrapper -->
<?php
require_once('../footer.php');
if (PrintMessage($_GET, $Message))
{
?>
<script type="text/javascript">
    alert('<?php echo $Message; ?>');
</script>
<?php
}
?>
<!-- DataTables JavaScript -->
<script src="/admin/vendor/datatables/js/jquery.dataTables.min.js"></script>
<script src="/admin/vendor/datatables-plugins/dataTables.bootstrap.min.js"></script>
<script src="/admin/vendor/datatables-responsive/dataTables.responsive.js"></script>    
<script type="text/javascript">
$(document).ready(function() {
    $('#DataTableRecords').DataTable({
        responsive: true,
        bPaginate: true,
        bSort: true,
        searching: true, 
        info: true
    });
});
</script>
<!-- JavaScript To Print A Report -->
<script src="/admin/js/print-report.js"></script>
</body>
</html>