<?php
require_once("../../classes/class.users.php");
require_once("../../classes/class.validation.php");
require_once("../../classes/class.authentication.php");

require_once("../../classes/inventory_management/class.product_categories.php");
require_once("../../classes/inventory_management/class.products.php");
require_once("../../classes/inventory_management/class.departments.php");
require_once("../../classes/school_administration/class.branch_staff.php");
require_once("../../classes/inventory_management/class.stock_issue.php");

require_once("../../classes/class.date_processing.php");

require_once("../../includes/global_defaults.inc.php");

//1. RECHECK IF THE USER IS VALID //
try
{
	$AuthObject = new ApplicationAuthentication;
	$LoggedUser = new User(0, $AuthObject->CheckValidUser());
}

// THIS CATCH BLOCK BUBBLES THE EXCEPTION TO THE BUILT IN 'Exception' CLASS IF THERE ARE ANY UNCAUGHT ERRORS //
catch (ApplicationAuthException $e)
{
	header('location:unauthorized_login_admin.php');
	exit;
}
catch (Exception $e)
{
	header('location:unauthorized_login_admin.php');
	exit;
}
// END OF 1. //

if ($LoggedUser->HasPermissionForTask(TASK_EDIT_STOCK_ISSUE) !== true)
{
	header('location:/admin/unauthorized_login_admin.php');
	exit;
}

$Clean = array();
$Clean['StockIssueID'] = 0;

if (isset($_GET['StockIssueID']))
{
    $Clean['StockIssueID'] = (int) $_GET['StockIssueID'];
}
elseif (isset($_POST['hdnStockIssueID']))
{
    $Clean['StockIssueID'] = (int) $_POST['hdnStockIssueID'];
}

if ($Clean['StockIssueID'] <= 0)
{
    header('location:../error.php');
    exit;
}   

try
{
    $StockIssueToEdit = new StockIssue($Clean['StockIssueID']);
}
catch (ApplicationDBException $e)
{
    header('location:../error.php');
    exit;
}
catch (Exception $e)
{
    header('location:../error.php');
    exit;
}

$StaffCategoryList = array('Teaching' => 'Teaching Staff', 'NonTeaching' => 'Non Teaching Staff');

$IssueTypeList = array('Staff' => 'Staff', 'Department' => 'Department');

$AllBranchStaffList = array();
$AllBranchStaffList = BranchStaff::GetActiveBranchStaff('Teaching');

$AllProductCategoryList = array();
$AllProductCategoryList = ProductCategory::GetActiveProductCategories();

$AllProductList = array();
$AllProductList = Product::GetProductsByProductCategoryID(key($AllProductCategoryList));

$ProductStockQuantity = Product::GetAvailabileStockQuantity(key($AllProductList));

$AllDepartmentList = array();
$AllDepartmentList = Department::GetActiveDepartments();

$HasErrors = false;

$Clean['Process'] = 0;

$Clean['ProductCategoryID'] = 0;
$Clean['ProductID'] = '';

$Clean['IssueType'] = 'Staff';
$Clean['DepartmentID'] = 0;

$Clean['StaffCategory'] = '';
$Clean['BranchStaffID'] = 0;

$Clean['IssuedQuantity'] = 0;
$Clean['IssueDate'] = '';
$Clean['ReturnDate'] = '';

if (isset($_POST['hdnProcess']))
{
	$Clean['Process'] = (int) $_POST['hdnProcess'];
}
else if (isset($_GET['Process']))
{
	$Clean['Process'] = (int) $_GET['Process'];
}
switch ($Clean['Process'])
{
	case 3:						
		if (isset($_POST['drdProductCategory']))
		{
			$Clean['ProductCategoryID'] = (int) $_POST['drdProductCategory'];
		}

		if (isset($_POST['drdProduct']))
		{
			$Clean['ProductID'] = (int) $_POST['drdProduct'];
		}

		if (isset($_POST['drdIssueType']))
		{
			$Clean['IssueType'] = strip_tags(trim($_POST['drdIssueType']));
		}

		if (isset($_POST['drdDepartment']))
		{
			$Clean['DepartmentID'] = (int) $_POST['drdDepartment'];
		}

		if (isset($_POST['drdStaffCategory']))
		{
			$Clean['StaffCategory'] = strip_tags(trim($_POST['drdStaffCategory']));
		}

		if (isset($_POST['drdBranchStaff']))
		{
			$Clean['BranchStaffID'] = (int) $_POST['drdBranchStaff'];
		}

		if (isset($_POST['txtIssuedQuantity']))
		{
			$Clean['IssuedQuantity'] = strip_tags(trim($_POST['txtIssuedQuantity']));
		}

		if (isset($_POST['txtIssueDate']))
		{
			$Clean['IssueDate'] = strip_tags(trim($_POST['txtIssueDate']));
		}

		if (isset($_POST['txtReturnDate']))
		{
			$Clean['ReturnDate'] = strip_tags(trim($_POST['txtReturnDate']));
		}
		
		$NewRecordValidator = new Validator();

		$NewRecordValidator->ValidateInSelect($Clean['ProductCategoryID'], $AllProductCategoryList, 'Unknown error, please try again.');

		if ($NewRecordValidator->HasNotifications())
		{
			$HasErrors = true;
			break;
		}

		$AllProductList = Product::GetProductsByProductCategoryID($Clean['ProductCategoryID']);

		$NewRecordValidator->ValidateInSelect($Clean['ProductID'], $AllProductList, 'Unknown error, please try again.');
		$NewRecordValidator->ValidateInSelect($Clean['IssueType'], $IssueTypeList, 'Unknown error, please try again.');
		$NewRecordValidator->ValidateInSelect($Clean['StaffCategory'], $StaffCategoryList, 'Unknown error, please try again.');
		$NewRecordValidator->ValidateInSelect($Clean['StaffCategory'], $StaffCategoryList, 'Unknown error, please try again.');

		$ProductStockQuantity = Product::GetAvailabileStockQuantity($Clean['ProductCategoryID']);

		if ($NewRecordValidator->HasNotifications())
		{
			$HasErrors = true;
			break;
		}

		$BranchStaffList = BranchStaff::GetActiveBranchStaff($Clean['StaffCategory']);

		$NewRecordValidator->ValidateInSelect($Clean['BranchStaffID'], $BranchStaffList, 'Unknown error, please try again.');
		$NewRecordValidator->ValidateInteger($Clean['IssuedQuantity'], 'Issued quantity should be integer.', 1);

		$NewRecordValidator->ValidateDate($Clean['IssueDate'], 'Please enter valid issue date.');

		$ReturnDate = '';
		if ($Clean['ReturnDate'] != '') 
		{
			$NewRecordValidator->ValidateDate($Clean['ReturnDate'], 'Please enter valid return  date.');
			$ReturnDate = date('Y-m-d',strtotime(DateProcessing::ToggleDateDayAndMonth($Clean['ReturnDate'])));

			if ($Clean['IssueDate'] <=  $Clean['ReturnDate']) 
			{
				$NewRecordValidator->AttachTextError('return  date cannot be less than issue date.');
			}
		}

		
		if ($NewRecordValidator->HasNotifications())
		{
			$HasErrors = true;
			break;
		}
				
		$StockIssueToEdit->SetProductID($Clean['ProductID']);
		$StockIssueToEdit->SetIssueType($Clean['IssueType']);
		$StockIssueToEdit->SetDepartmentID($Clean['DepartmentID']);
		$StockIssueToEdit->SetBranchStaffID($Clean['BranchStaffID']);
		$StockIssueToEdit->SetIssuedQuantity($Clean['IssuedQuantity']);
		$StockIssueToEdit->SetIssueDate(date('Y-m-d',strtotime(DateProcessing::ToggleDateDayAndMonth($Clean['IssueDate']))));
		$StockIssueToEdit->SetReturnDate($ReturnDate);
		
		$StockIssueToEdit->SetCreateUserID($LoggedUser->GetUserID());

		if (StockIssue::IsStockAvailable($Clean['StockIssueID'])) 
		{
			$NewRecordValidator->AttachTextError('Stock not available, product can not change.');
            $HasErrors = true;
            break;
		}

		if (($ProductStockQuantity - $Clean['IssuedQuantity']) <= 0) 
		{
			$NewRecordValidator->AttachTextError('product not in stock.');
            $HasErrors = true;
            break;
		}

		if (!$StockIssueToEdit->Save())
		{
			$NewRecordValidator->AttachTextError(ProcessErrors($StockIssueToEdit->GetLastErrorCode()));
			$HasErrors = true;
			break;
		}
		
		header('location:stock_issues_list.php?Mode=UD');
		exit;
		break;

	case 2;
		$Clean['ProductID'] = $StockIssueToEdit->GetProductID();
		$ProductDetails = new Product($Clean['ProductID']);
		$Clean['ProductCategoryID'] = $ProductDetails->GetProductCategoryID();

		$Clean['IssueType'] = $StockIssueToEdit->GetIssueType();
		$Clean['DepartmentID'] = $StockIssueToEdit->GetDepartmentID();

		$Clean['BranchStaffID'] = $StockIssueToEdit->GetBranchStaffID();
		$BranchStaffDetails = new BranchStaff($Clean['BranchStaffID']);
		$Clean['StaffCategory'] = $BranchStaffDetails->GetStaffCategory();

		$Clean['IssuedQuantity'] = $StockIssueToEdit->GetIssuedQuantity();
		$Clean['IssueDate'] = $StockIssueToEdit->GetIssueDate();
		$Clean['ReturnDate'] = $StockIssueToEdit->GetReturnDate();
		break;
}

require_once('../html_header.php');
?>
<title>Edit Stock Issue</title>
<link href="../vendor/jquery-ui/jquery-ui.min.css" rel="stylesheet">
</head>

<body>

    <div id="wrapper">
    	<!-- Navigation -->
        <nav class="navbar navbar-default navbar-static-top" role="navigation" style="margin-bottom: 0">
<?php 
			require_once('../site_header.php');
			require_once('../left_navigation_menu.php');
?>                    
            <!-- /.navbar-static-side -->
        </nav>

        <div id="page-wrapper">
            <div class="row">
                <div class="col-lg-12">
                    <h1 class="page-header">Edit Stock Issue</h1>
                </div>
                <!-- /.col-lg-12 -->
            </div>
             <form class="form-horizontal" name="EditStockIssue" action="edit_stock_issue.php" method="post">
            	<div class="panel panel-default">
                    <div class="panel-heading">
                        Enter Stock Issue Details
                    </div>
                    <div class="panel-body">
<?php
						if ($HasErrors == true)
						{
							echo $NewRecordValidator->DisplayErrors();
						}
?>                    
                    	<div class="form-group">
                    		<label for="ProductCategory" class="col-lg-2 control-label">Product Category</label>
                    		<div class="col-lg-4">
	                            <select class="form-control" name="drdProductCategory" id="ProductCategory">
<?php
								foreach ($AllProductCategoryList as $ProductCategoryID => $ProductCategoryName)
								{
?>
									<option <?php echo ($Clean['ProductCategoryID'] == $ProductCategoryID) ? 'selected="selected"' : ''; ?> value="<?php echo $ProductCategoryID; ?>"><?php echo $ProductCategoryName; ?></option>
<?php
								}
?>
								</select>
							</div>
							<label for="Product" class="col-lg-2 control-label">Product</label>
							<div class="col-lg-4">
								<select class="form-control" name="drdProduct" id="Product">
<?php
								foreach ($AllProductList as $ProductID => $ProductName)
								{
?>
									<option <?php echo ($Clean['ProductID'] == $ProductID) ? 'selected="selected"' : ''; ?> value="<?php echo $ProductID; ?>"><?php echo $ProductName; ?></option>
<?php
								}
?>
								</select>
								<span id="StockQuantity" style="color: red;">Product Stock Quantity = <?php echo $ProductStockQuantity;?></span>
							</div>
						</div>
						<div class="form-group">
                    		<label for="IssueType" class="col-lg-2 control-label">Issue Type</label>
                    		<div class="col-lg-4">
	                            <select class="form-control" name="drdIssueType">
<?php
								foreach ($IssueTypeList as $IssueType => $IssueTypeName)
								{
?>
									<option <?php echo ($Clean['IssueType'] == $IssueType) ? 'selected="selected"' : ''; ?> value="<?php echo $IssueType; ?>"><?php echo $IssueTypeName; ?></option>
<?php
								}
?>
								</select>
							</div>
							<label for="Department" class="col-lg-2 control-label">Department</label>
							<div class="col-lg-4">
								<select class="form-control" name="drdDepartment" <?php echo($Clean['IssueType'] == 'Staff') ? 'disabled="disabled"' : ''?>>
<?php
								foreach ($AllDepartmentList as $DepartmentID => $DepartmentName)
								{
?>
									<option <?php echo ($Clean['DepartmentID'] == $DepartmentID) ? 'selected="selected"' : ''; ?> value="<?php echo $DepartmentID; ?>"><?php echo $DepartmentName; ?></option>
<?php
								}
?>
								</select>
							</div>
                        </div>
                        <div class="form-group">
	                        <label for="StaffCategory" class="col-lg-2 control-label">Staff Category</label>
	                        <div class="col-lg-4">
	                            <select class="form-control" name="drdStaffCategory" id="StaffCategory">
<?php
                                foreach ($StaffCategoryList as $StaffCategory => $StaffCategoryName)
                                {
?>
                                    <option <?php echo ($StaffCategory == $Clean['StaffCategory'] ? 'selected="selected"' : ''); ?> value="<?php echo $StaffCategory; ?>"><?php echo $StaffCategoryName; ?></option>
<?php
                                }
?>
	                            </select>
	                        </div>
	                        <label for="BranchStaff" class="col-lg-2 control-label">Branch Staff</label>
	                        <div class="col-lg-4">
	                            <select class="form-control"  name="drdBranchStaff" id="BranchStaffID">
<?php
                                foreach ($AllBranchStaffList as $BranchStaffID => $BranchStaffName)
                                {
?>
                                    <option <?php echo ($BranchStaffID == $Clean['BranchStaffID'] ? 'selected="selected"' : ''); ?> value="<?php echo $BranchStaffID; ?>"><?php echo $BranchStaffName['FirstName'] . " ". $BranchStaffName['LastName']; ?></option>
<?php
                                }
?>
	                            </select>
	                        </div>
	                    </div>
	                    <div class="form-group">
	                        <label for="IssuedQuantity" class="col-lg-2 control-label">Issued Quantity</label>
                            <div class="col-lg-4">
                            	<input class="form-control" type="text" name="txtIssuedQuantity" value="<?php echo ($Clean['IssuedQuantity']) ? $Clean['IssuedQuantity'] : ''; ?>"/>	
                            </div>
	                    </div> 
	                    <div class="form-group">
	                        <label for="IssueDate" class="col-lg-2 control-label">Issue Date</label>
                            <div class="col-lg-4">
                            	<input class="form-control dtepicker" type="text" name="txtIssueDate" value="<?php echo($Clean['IssueDate'] == '') ? ''  : date('d/m/Y',strtotime($Clean['IssueDate'])); ?>"/>	
                            </div>
	                        <label for="ReturnDate" class="col-lg-2 control-label">Return Date</label>
                            <div class="col-lg-4">
                            	<input class="form-control dtepicker" type="text" name="txtReturnDate" value="<?php echo($Clean['ReturnDate']) ? ''  : date('d/m/Y',strtotime($Clean['IssueDate'])); ?>"/>	
                            </div>
	                    </div> 
                        <div class="form-group">
                        <div class="col-sm-offset-2 col-lg-10">
                        	<input type="hidden" name="hdnProcess" value="3" />
                        	<input type="hidden" name="hdnStockIssueID" value="<?php echo $Clean['StockIssueID'];?>" />
							<button type="submit" class="btn btn-primary">Save</button>
                        </div>
                      </div>
                    </div>
                </div>
            </form>
        </div>
        <!-- /#page-wrapper -->

    </div>
    <!-- /#wrapper -->
<?php
require_once('../footer.php');
?>
<script src="/admin/vendor/jquery-ui/jquery-ui.min.js"></script>
<script type="text/javascript">
$(document).ready(function() 
{
    $(".dtepicker").datepicker({
            changeMonth: true,
            changeYear: true,
            dateFormat: 'dd/mm/yy'
    });

    $('#ProductCategory').change(function() 
	{
		var ProductCategoryID = parseInt($(this).val());

		if (ProductCategoryID <= 0)
		{
			alert("Please Select Product Category");
			return false;
		}

		$.get("/xhttp_calls/get_products_by_product_category.php", {SelectedProductCategoryID: ProductCategoryID}, function(data)
		{	
			ResultArray = data.split("|*****|");
	
			if (ResultArray[0] == 'error')
			{
				alert (ResultArray[1]);
				$('#Product').html('<option value="0">Select</option>');
				return false;
			}
			else
			{	
				$('#Product').html(ResultArray[1]);

				GetProductStockQuantity(parseInt($('#Product').val()));
			}			
		});
	});

    $('#StaffCategory').change(function()
	{

		StaffCategory = $(this).val();
		
		if (StaffCategory <= 0)
		{
			$('#BranchStaffID').html('<option value="0">Select Section</option>');
			return;
		}
		
		$.post("/xhttp_calls/get_branch_staff_by_staff_category.php", {SelectedStaffCategory:StaffCategory}, function(data)
		{
		
			ResultArray = data.split("|*****|");
			
			if (ResultArray[0] == 'error')
			{
				alert(ResultArray[1]);
				$('#StaffCategory').val(StaffCategoryBeforeChange);
			}
			else
			{
				$('#BranchStaffID').html(ResultArray[1]);
			}
		 });
	});

	$('#IssueType').change(function()
	{
		if ($(this).val() == 'Staff') 
		{
			$('#Department').attr('disabled', true);
			return true;
		}

		$('#Department').attr('disabled', false);
			return true;
	});
});

function GetProductStockQuantity(Product)
{	
	$.post("/xhttp_calls/get_product_stock_quantity_by_product.php", {ProductID:Product}, function(data)
		{
		
			ResultArray = data.split("|*****|");
			
			if (ResultArray[0] == 'error')
			{
				alert(ResultArray[1]);
			}
			else
			{		
				$('#StockQuantity').html(ResultArray[1]);
			}
		 });
}
</script>
</body>
</html>