<?php
require_once("../../../classes/class.users.php");
require_once("../../../classes/class.validation.php");
require_once("../../../classes/class.authentication.php");

require_once("../../../classes/school_administration/class.students.php");
require_once("../../../classes/school_administration/class.parent_details.php");
require_once("../../../classes/school_administration/class.student_details.php");

require_once("../../../classes/school_administration/class.classes.php");
require_once("../../../classes/school_administration/class.section_master.php");
require_once("../../../classes/school_administration/class.class_sections.php");

require_once("../../../classes/class.date_processing.php");
require_once("../../../includes/global_defaults.inc.php");

//1. RECHECK IF THE USER IS VALID //
try
{
    $AuthObject = new ApplicationAuthentication;
    $LoggedUser = new User(0, $AuthObject->CheckValidUser());
}

// THIS CATCH BLOCK BUBBLES THE EXCEPTION TO THE BUILT IN 'Exception' CLASS IF THERE ARE ANY UNCAUGHT ERRORS //
catch (ApplicationAuthException $e)
{
    header('location:/admin/unauthorized_login_admin.php');
    exit;
}
catch (Exception $e)
{
    header('location:/admin/unauthorized_login_admin.php');
    exit;
}
// END OF 1. //

if ($LoggedUser->HasPermissionForTask(TASK_EDIT_STUDENT) !== true)
{
	header('location:/admin/unauthorized_login_admin.php');
	exit;
}

$HasErrors = false;

$SchoolName = 'SHIVA PUBLIC SCHOOL';
$AffilationDetails = 'Affiliated C.B.S.E Board New Delhi';
$Address = 'Tiloi Distt. Amethi (U.P.)';
$Pincode = 229309;
$City = 'Amethi';
$State = 'UP';
$ContactNumber = '0535-2634282';
$AffilationNumber = '2132953';

$Clean = array();

$Clean['StudentIDList'] = array('103'=>1);

if (isset($_GET['StudentIDList']))
{
    $Clean['StudentIDList'] = explode(',', $_GET['StudentIDList']);
}

if (count($Clean['StudentIDList']) <= 0)
{
    header('location:../../error.php');
    exit;
}   

$IDCardDetails = array();

foreach ($Clean['StudentIDList'] as $StudentID)
{
    try
    {
        $StudentObject = new StudentDetail($StudentID);
        
        $NewParentDetail = new ParentDetail($StudentObject->GetParentID());
        $ClassSectionDetails = new ClassSections($StudentObject->GetClassSectionID());
        
        $ClassObject = new AddedClass($ClassSectionDetails->GetClassID());
        $SectionObject = new SectionMaster($ClassSectionDetails->GetSectionMasterID());
    }
    catch (ApplicationDBException $e)
    {
        header('location:../../error.php');
        exit;
    }
    catch (Exception $e)
    {
        header('location:../../error.php');
        exit;
    }
    
    $StudentPhoto = '/images/profile-dummy.png';
    
    if (file_exists(SITE_FS_PATH . '/site_images/student_images/' . $StudentObject->GetStudentID() . '/' . $StudentObject->GetStudentPhoto()))
    {
        $StudentPhoto = '/site_images/student_images/' . $StudentObject->GetStudentID() . '/' . $StudentObject->GetStudentPhoto();
    }
    
    $IDCardDetails[$StudentObject->GetStudentID()]['FirstName'] = $StudentObject->GetFirstName();
    $IDCardDetails[$StudentObject->GetStudentID()]['LastName'] = $StudentObject->GetLastName();
    
    $IDCardDetails[$StudentObject->GetStudentID()]['FatherFirstName'] = $NewParentDetail->GetFatherFirstName();
    $IDCardDetails[$StudentObject->GetStudentID()]['FatherLastName'] = $NewParentDetail->GetFatherLastName();
    
    $IDCardDetails[$StudentObject->GetStudentID()]['FatherMobileNumber'] = $NewParentDetail->GetFatherMobileNumber();
    
    $IDCardDetails[$StudentObject->GetStudentID()]['ClassName'] = $ClassObject->GetClassName();
    $IDCardDetails[$StudentObject->GetStudentID()]['SectionName'] = $SectionObject->GetSectionName();
    
    $IDCardDetails[$StudentObject->GetStudentID()]['StudentPhoto'] = $StudentPhoto;
}

//echo '<pre>';
//var_dump($IDCardDetails);exit;
require_once('../../html_header.php');
?>
<title>Student ID Card</title>
<link href="../../vendor/jquery-ui/jquery-ui.min.css" rel="stylesheet">
<link href="style.css" rel="stylesheet">
</head>

<body>

    <div id="wrapper">
        <!-- Navigation -->
        <nav class="navbar navbar-default navbar-static-top" role="navigation" style="margin-bottom: 0">
<?php 
            require_once('../../site_header.php');
            require_once('../../left_navigation_menu.php');
?>                    
            <!-- /.navbar-static-side -->
        </nav>

        <div id="page-wrapper">
            <div class="row">
                <div class="col-lg-12">
                    <h1 class="page-header">Student ID Card</h1>
                </div>
                <!-- /.col-lg-12 -->
            </div>
            <div class="panel panel-default">
                <div class="panel-heading">
                    <strong>Student List</strong>
                </div>
                <div class="panel-body">
                    <div>
                        <div class="row">
                            <div class="col-lg-6">                                     
                            </div>
                            <div class="col-lg-6">
                                <div class="print-btn-container"><button id="PrintButton" type="submit" class="btn btn-primary">Print</button></div>
                            </div>
                        </div>
                        <div class="row" id="RecordTableHeading" style="margin-left:120px;">
<?php
                        $Counter = 0;
                        foreach ($IDCardDetails as $StudentID => $IDCardDetails)
                        {
                            $Counter++;
?>
                            <div class="card col-sm-6">
                                <div class="id-card-header">
                                    <table>
                                        <tr>
                                            <td width="100">
                                                <img src="../../../site_images/school_logo/shiva-public-logo.jpg" height="70px;" width="80px;" style="" align="center;">
                                            </td>
                                            <td>
                                                <div class="organization-info">
                                                    <strong style="font-size:15px;"><?php echo $SchoolName; ?></strong>
                                                    <p style="margin-bottom:2px; height:10px;"><strong style="font-size:10px;"><?php echo $AffilationDetails; ?></strong></p>
                                                    <p style="margin-bottom:2px; height:10px;"><strong style="font-size:10px;"><?php echo $Address; ?></strong></p>
                                                    <p style="margin-bottom:2px; height:10px;"><strong style="font-size:10px;"><?php echo 'Phone No. '. $ContactNumber; ?></strong></p>
                                                </div>
                                            </td>
                                        </tr>
                                    </table>
                                </div>
                                
                                <div class="id-card-container">
                                    <p style="text-align:center; margin:5px; margin-top:0px; font-size:14px;"><u>Indentity Card</u></p>
                                    <table>
                                        <tr>
                                            <td><img src="<?php echo $IDCardDetails['StudentPhoto']; ?>" height="88" width="75" /></td>
                                            <td style="padding-left: 10px;">
                                                <strong  style="margin-bottom:8px;"><?php echo strtoupper($IDCardDetails['FirstName'] . ' ' . $IDCardDetails['LastName']); ?></strong>
                                                <p style="margin-bottom:5px;"><?php echo strtoupper($IDCardDetails['FatherFirstName'] . ' ' . $IDCardDetails['FatherLastName']); ?></p>
                                                <p style="margin-bottom:5px;"><?php echo $IDCardDetails['ClassName'] . ' (' . $IDCardDetails['SectionName'] . ')'; ?></p>
                                                <p style="margin-bottom:5px; color:red;"><b><?php echo $IDCardDetails['FatherMobileNumber'] ? $IDCardDetails['FatherMobileNumber'] : '&nbsp;'; ?></b></p>
                                            </td>
                                        </tr>
                                    </table>
                                </div>
                            </div>
<?php
                            if ($Counter % 10 == 0)
                            {
                                echo '<p style="page-break-after: always"></p>';
                            }
                        }
?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- /#page-wrapper -->

    </div>
    <!-- /#wrapper -->
<?php
require_once('../../footer.php');
?>
<script src="js/print.js"></script>
<script type="text/javascript">
    $(document).ready(function () {
        $('.unique-function').click(function () {

            var DataValue = prompt('Enter Details', $(this).text().trim());
            if (DataValue)
            {
                $(this).html('&nbsp;&nbsp;<b>' + DataValue + '</b>');
            }
        });
    });
</script>
</body>
</html>