<?php

require_once('../../classes/class.users.php');
require_once('../../classes/class.validation.php');
require_once('../../classes/class.authentication.php');
require_once('../../classes/class.date_processing.php');

require_once('../../classes/school_administration/class.academic_years.php');
require_once('../../classes/school_administration/class.academic_year_months.php');

require_once('../../classes/school_administration/class.classes.php');
require_once('../../classes/school_administration/class.class_sections.php');
require_once('../../classes/school_administration/class.students.php');
require_once('../../classes/school_administration/class.student_details.php');

require_once('../../classes/school_administration/class.student_tc_details.php');

require_once('../../classes/fee_management/class.fee_collection.php');
require_once("../../classes/library_management/class.book_issue.php");

require_once('../../classes/class.global_settings.php');

require_once('../../includes/global_defaults.inc.php');

//1. RECHECK IF THE USER IS VALID //
try
{
	$AuthObject = new ApplicationAuthentication;
	$LoggedUser = new User(0, $AuthObject->CheckValidUser());
}

// THIS CATCH BLOCK BUBBLES THE EXCEPTION TO THE BUILT IN 'Exception' CLASS IF THERE ARE ANY UNCAUGHT ERRORS //
catch (ApplicationAuthException $e)
{
	header('location:../unauthorized_login_admin.php');
	exit;
}
catch (Exception $e)
{
	header('location:../unauthorized_login_admin.php');
	exit;
}
// END OF 1. //

if ($LoggedUser->HasPermissionForTask(TASK_GENERATE_REPORT_CARD) !== true)
{
	header('location:/admin/unauthorized_login_admin.php');
	exit;
}

$AcademicYears =  array();
$AcademicYears = AcademicYear::GetAllAcademicYears();

$AcademicYearMonths =  array();
$AcademicYearMonths =  AcademicYearMonth::GetMonthsByFeePriority();

$GlobalSettingObject = new GlobalSetting();

$FeeSubmissionLastDate = '';
$FeeSubmissionFrequency = 0;
$FeeSubmissionType = '';

$FeeSubmissionLastDate = $GlobalSettingObject->GetFeeSubmissionLastDate();
$FeeSubmissionFrequency = $GlobalSettingObject->GetFeeSubmissionFrequency();
$FeeSubmissionType = $GlobalSettingObject->GetFeeSubmissionType();

$AcademicYearMonthID = 0;
$AcademicYearMonthID = AcademicYearMonth::GetMonthIDByMonthName(date('M'));

$FeePriority = 0;

foreach (array_chunk($AcademicYearMonths, $FeeSubmissionFrequency, true) as $Key => $Value) 
{
    if (array_key_exists($AcademicYearMonthID, $Value)) 
    {
        end($Value);
        $FeePriority = $Value[key($Value)]['FeePriority'];
    }
}

$ClassList =  array();
$ClassList = AddedClass::GetActiveClasses();

$ClassSectionsList = array();

$HasErrors = false;
$SearchErrors = false;

$Clean = array();
$Clean['Process'] = 0;

$Clean['AcademicYearID'] = 0;
$Clean['ClassID'] = 0;
$Clean['ClassSectionID'] = 0;

$Clean['LastDateOfSession'] = '';
$Clean['TcIssueDate'] = '';
$Clean['SchoolLeavingDate'] = '';
$Clean['SchoolLeavingDate'] = '';
$Clean['ReasonOfLeaving'] = '';

$LastDateOfSession = '';
$TcIssueDate = '';
$SchoolLeavingDate = '';

$Clean['StudentIDList'] = array();

$StudentsList = array();
$FeeDues = array();
$LibraryDues = array();
$InventoryDues = array();

$TotalRecords = 0;

if (isset($_POST['hdnProcess']))
{
	$Clean['Process'] = (int) $_POST['hdnProcess'];
}
switch ($Clean['Process'])
{
	case 1:
	    if (isset($_POST['hdnAcademicYearID'])) 
		{
			$Clean['AcademicYearID'] = (int) $_POST['hdnAcademicYearID'];
		}
		
		if (isset($_POST['hdnClassID'])) 
        {
            $Clean['ClassID'] = (int) $_POST['hdnClassID'];
        }
        
        if (isset($_POST['hdnClassSection'])) 
        {
            $Clean['ClassSectionID'] = (int) $_POST['hdnClassSection'];
        }

        if (isset($_POST['chkStudentList']) && is_array($_POST['chkStudentList'])) 
        {
            $Clean['StudentIDList'] = $_POST['chkStudentList'];
        }
        
        if (isset($_POST['hdnSchoolLeavingDate'])) 
        {
            $Clean['SchoolLeavingDate'] = strip_tags(trim($_POST['hdnSchoolLeavingDate']));
        }
        
        if (isset($_POST['hdnLastDateOfSession'])) 
        {
            $Clean['LastDateOfSession'] = strip_tags(trim($_POST['hdnLastDateOfSession']));
        }
        
        if (isset($_POST['hdnTcIssueDate'])) 
        {
            $Clean['TcIssueDate'] = strip_tags(trim($_POST['hdnTcIssueDate']));
        }
        
        if (isset($_POST['hdnReasonOfLeaving'])) 
        {
            $Clean['ReasonOfLeaving'] = strip_tags(trim($_POST['hdnReasonOfLeaving']));
        }

		$NewRecordValidator = new Validator();

		if ($NewRecordValidator->ValidateInSelect($Clean['ClassID'], $ClassList, 'Unknown error, please try again.')) 
		{
			$ClassSectionsList = ClassSections::GetClassSections($Clean['ClassID']);
            
            $NewRecordValidator->ValidateInSelect($Clean['ClassSectionID'], $ClassSectionsList, 'Unknown error, please try again.');
            
            // $StudentsList = StudentDetail::GetStudentsByClassSectionID($Clean['ClassSectionID'], 'Active');
            $StudentsList = StudentDetail::GetStudentsByClassSectionID_NEW_FOR_TC($Clean['ClassSectionID'], 'Active', $Clean['AcademicYearID']);

            $SelectedStudents = '';

            if (count($Clean['StudentIDList']) <= 0) 
            {
                $NewRecordValidator->AttachTextError('Please select at least one student.');
                $SearchErrors = true;
                break;
            }
            
            // echo '<pre>';
            // print_r($Clean);
            // print_r($StudentsList);
            // exit;

            foreach ($Clean['StudentIDList'] as $Key => $StudentID) 
            {
                if (!array_key_exists($StudentID, $StudentsList)) 
                {
                    header('location:admin/error.php');
                }
            }
            
            $SelectedStudents = implode(',', $Clean['StudentIDList']);
		}
		
		if ($Clean['LastDateOfSession'] != '')
        {
            $NewRecordValidator->ValidateDate($Clean['LastDateOfSession'], 'Please enter a valid session last date.');
        }
        
        if ($Clean['TcIssueDate'] != '')
        {
            $NewRecordValidator->ValidateDate($Clean['TcIssueDate'], 'Please enter a valid TC issue date.');
        }
        
        if ($Clean['SchoolLeavingDate'] != '')
        {
            $NewRecordValidator->ValidateDate($Clean['SchoolLeavingDate'], 'Please enter a valid school leaving date.');
        }
        
		if ($NewRecordValidator->HasNotifications())
		{
			$SearchErrors = true;
			break;
		}
		
		if ($Clean['LastDateOfSession'] != '')
        {
            $LastDateOfSession = date('Y-m-d', strtotime(DateProcessing::ToggleDateDayAndMonth(($Clean['LastDateOfSession']))));
        }
        
        if ($Clean['TcIssueDate'] != '')
        {
            $TcIssueDate = date('Y-m-d', strtotime(DateProcessing::ToggleDateDayAndMonth(($Clean['TcIssueDate']))));
        }
        
        if ($Clean['SchoolLeavingDate'] != '')
        {
            $SchoolLeavingDate = date('Y-m-d', strtotime(DateProcessing::ToggleDateDayAndMonth(($Clean['SchoolLeavingDate']))));
        }

        $NewStudentTcDetail = new StudentTcDetail();

        $NewStudentTcDetail->SetStudentIDList($Clean['StudentIDList']);

        $NewStudentTcDetail->SetLastDateOfSession($LastDateOfSession);
        $NewStudentTcDetail->SetTcIssueDate($TcIssueDate);
        $NewStudentTcDetail->SetSchoolLeavingDate($SchoolLeavingDate);
       
        $NewStudentTcDetail->SetReasonOfLeaving($Clean['ReasonOfLeaving']);
        $NewStudentTcDetail->SetCreateUserID($LoggedUser->GetUserID());

        if (!$NewStudentTcDetail->Save())
		{
            $NewRecordValidator->AttachTextError(ProcessErrors($NewStudentTcDetail->GetLastErrorCode()));
			$HasErrors = true;
			break;
		}
        
		header('location:certificate_formats/transfer_certificate.php?SelectedStudents='.$SelectedStudents . '&ClassSectionID=' . $Clean['ClassSectionID']);
		exit;
	break;

    case 7:
        if (isset($_POST['drdAcademicYear'])) 
		{
			$Clean['AcademicYearID'] = (int) $_POST['drdAcademicYear'];
		}
        if (isset($_POST['drdClass'])) 
        {
            $Clean['ClassID'] = (int) $_POST['drdClass'];
        }

        if (isset($_POST['drdClassSection'])) 
        {
            $Clean['ClassSectionID'] = (int) $_POST['drdClassSection'];
        }
        
        if (isset($_POST['txtLastDateOfSession'])) 
        {
            $Clean['LastDateOfSession'] = strip_tags(trim($_POST['txtLastDateOfSession']));
        }
        
        if (isset($_POST['txtTcIssueDate'])) 
        {
            $Clean['TcIssueDate'] = strip_tags(trim($_POST['txtTcIssueDate']));
        }
        
        if (isset($_POST['txtSchoolLeavingDate'])) 
        {
            $Clean['SchoolLeavingDate'] = strip_tags(trim($_POST['txtSchoolLeavingDate']));
        }
        
        if (isset($_POST['drdReasonOfLeaving']))
        {
            $Clean['ReasonOfLeaving'] = strip_tags(trim($_POST['drdReasonOfLeaving']));
        }

        $NewRecordValidator = new Validator();

        if ($NewRecordValidator->ValidateInSelect($Clean['ClassID'], $ClassList, 'Please select a class.')) 
        {
            $ClassSectionsList = ClassSections::GetClassSections($Clean['ClassID']);
            
            $NewRecordValidator->ValidateInSelect($Clean['ClassSectionID'], $ClassSectionsList, 'Please select a section.');
        }
        
        if ($Clean['LastDateOfSession'] != '')
        {
            $NewRecordValidator->ValidateDate($Clean['LastDateOfSession'], 'Please enter a valid session last date.');
        }
        
        if ($Clean['TcIssueDate'] != '')
        {
            $NewRecordValidator->ValidateDate($Clean['TcIssueDate'], 'Please enter a valid TC issue date.');
        }
        
        if ($Clean['SchoolLeavingDate'] != '')
        {
            $NewRecordValidator->ValidateDate($Clean['SchoolLeavingDate'], 'Please enter a valid school leaving date.');
        }
        
        if ($NewRecordValidator->HasNotifications())
        {
            $HasErrors = true;
            break;
        }
        
        // $StudentsList = StudentDetail::GetStudentsByClassSectionID($Clean['ClassSectionID'], 'Active');
        $StudentsList = StudentDetail::GetStudentsByClassSectionID_NEW_FOR_TC($Clean['ClassSectionID'], 'Passout', $Clean['AcademicYearID']);
        
        $Filters['ClassID'] = $Clean['ClassID'];
        $Filters['ClassSectionID'] = $Clean['ClassSectionID'];
        
        //get records count
        FeeCollection::SearchFeeDefaulters($TotalRecords, true, $Filters, $FeePriority);
        
        $FeeDuesList = FeeCollection::SearchFeeDefaulters($TotalRecords, false, $Filters, $FeePriority, 0, $TotalRecords);
        
    break;
}

require_once('../html_header.php');
?>
<title>Generate Transfer Certificate</title>
<!--<link href="vendor/jquery-ui/jquery-ui.min.css" rel="stylesheet">-->
<link href="../vendor/jquery-ui/jquery-ui.min.css" rel="stylesheet">
</head>

<body>

    <div id="wrapper">
        <!-- Navigation -->
        <nav class="navbar navbar-default navbar-static-top" role="navigation" style="margin-bottom: 0">
            <?php 
			require_once('../site_header.php');
			require_once('../left_navigation_menu.php');
?>
            <!-- /.navbar-static-side -->
        </nav>

        <div id="page-wrapper">
            <div class="row">
                <div class="col-lg-12">
                    <h1 class="page-header">Generate Transfer Certificate</h1>
                </div>
                <!-- /.col-lg-12 -->
            </div>
            <form class="form-horizontal" name="GenerateTransferCertificate" action="generate_tc.php" method="post">
                <div class="panel panel-default">
                    <div class="panel-heading">
                        Enter Details
                    </div>
                    <div class="panel-body">
                        <?php
						if ($HasErrors == true)
						{
							echo $NewRecordValidator->DisplayErrorsInTable();
						}
?>
                        <br>
                        <div class="form-group">
                            <label for="AcademicYearID" class="col-lg-2 control-label">Academic Session</label>
                            <div class="col-lg-4">
                                <select class="form-control" name="drdAcademicYear" id="AcademicYearID">
                                    <?php
                                if (is_array($AcademicYears) && count($AcademicYears) > 0)
                                {
                                    foreach ($AcademicYears as $AcademicYearID => $AcademicYearDetails)
                                    {
                                        if ($Clean['AcademicYearID'] == 0)
                                        {
                                            if ($AcademicYearDetails['IsCurrentYear'] == 1)
                                            {
                                                $Clean['AcademicYearID'] = $AcademicYearID;   
                                            }
                                        }
                                        
                                        echo '<option ' . ($Clean['AcademicYearID'] == $AcademicYearID ? 'selected="selected"' : '') . ' value="' . $AcademicYearID . '">' . date('Y', strtotime($AcademicYearDetails['StartDate'])) .' - '. date('Y', strtotime($AcademicYearDetails['EndDate'])) . '</option>';
                                    }
                                }
?>
                                </select>
                            </div>
                        </div>
                        <div class="form-group">
                            <label for="Class" class="col-lg-2 control-label">Class</label>
                            <div class="col-lg-4">
                                <select class="form-control" name="drdClass" id="Class">
                                    <option value="0">-- Select Class --</option>
                                    <?php
                                    if (is_array($ClassList) && count($ClassList) > 0)
                                    {
                                        foreach ($ClassList as $ClassID => $ClassName)
                                        {
?>
                                    <option <?php echo ($ClassID == $Clean['ClassID'] ? 'selected="selected"' : ''); ?>
                                        value="<?php echo $ClassID; ?>"><?php echo $ClassName; ?></option>
                                    <?php
                                        }
                                    }
?>
                                </select>
                            </div>
                            <label for="Class" class="col-lg-2 control-label">Section</label>
                            <div class="col-lg-4">
                                <select class="form-control" name="drdClassSection" id="ClassSection">
                                    <option value="0">-- Select Section --</option>
                                    <?php
                                if (is_array($ClassSectionsList) && count($ClassSectionsList) > 0)
                                {
                                    foreach ($ClassSectionsList as $ClassSectionID => $SectionName) 
                                    {
                                        echo '<option '.($Clean['ClassSectionID'] == $ClassSectionID ? 'selected="selected"' : '') .' value="'. $ClassSectionID .'">'. $SectionName .'</option>';
                                    }
                                }
?>
                                </select>
                            </div>
                        </div>
                        <div class="form-group">
                            <label for="LastDateOfSession" class="col-lg-2 control-label">Last Date Of Session</label>
                            <div class="col-lg-4">
                                <input class="form-control select-date" type="text" maxlength="10"
                                    id="LastDateOfSession" name="txtLastDateOfSession"
                                    value="<?php echo $Clean['LastDateOfSession'] ; ?>" />
                            </div>
                            <label for="TcIssueDate" class="col-lg-2 control-label">Tc Issue Date</label>
                            <div class="col-lg-4">
                                <input class="form-control select-date" type="text" maxlength="10" id="TcIssueDate"
                                    name="txtTcIssueDate" value="<?php echo $Clean['TcIssueDate']; ?>" />
                            </div>
                        </div>
                        <div class="form-group">
                            <label for="SchoolLeavingDate" class="col-lg-2 control-label">School Leaving Date</label>
                            <div class="col-lg-4">
                                <input class="form-control select-date" type="text" maxlength="10"
                                    id="SchoolLeavingDate" name="txtSchoolLeavingDate"
                                    value="<?php echo $Clean['SchoolLeavingDate']; ?>" />
                            </div>
                            <label for="ReasonOfLeaving" class="col-lg-2 control-label">Reason For Leaving</label>
                            <div class="col-lg-4">
                                <select class="form-control" name="drdReasonOfLeaving" id="ReasonOfLeaving">
                                    <option value="">-- Select --</option>
                                    <option value="Parent`s wish"
                                        <?php echo ($Clean['ReasonOfLeaving'] == 'Parent`s wish' ? 'selected="selected"' : ''); ?>>
                                        Parent`s wish </option>
                                    <option value="Parent transfered"
                                        <?php echo ($Clean['ReasonOfLeaving'] == 'Parent transfered' ? 'selected="selected"' : ''); ?>>
                                        Parent transfered</option>
                                    <option value="Last class passed"
                                        <?php echo ($Clean['ReasonOfLeaving'] == 'Last class passed' ? 'selected="selected"' : ''); ?>>
                                        Last class passed</option>
                                    <option value="Other"
                                        <?php echo ($Clean['ReasonOfLeaving'] == 'Other' ? 'selected="selected"' : ''); ?>>
                                        Other</option>
                                </select>
                            </div>
                        </div>

                        <div class="form-group">
                            <div class="col-sm-offset-2 col-lg-10">
                                <input type="hidden" name="hdnProcess" value="7" />
                                <button type="submit" class="btn btn-primary"><i
                                        class="fa fa-search"></i>&nbsp;Search</button>
                            </div>
                        </div>
                    </div>
                </div>
            </form>

            <?php
        if ($Clean['Process'] == 7 && $HasErrors == false || $Clean['Process'] == 1)
        {
?>
            <!-- /.row -->
            <div class="row">
                <div class="col-lg-12">
                    <div class="panel panel-default">
                        <div class="panel-body">
                            <div>
                                <?php
                            if ($SearchErrors == true)
                            {
                                echo $NewRecordValidator->DisplayErrorsInTable();
                            }
?>
                                <form class="form-horizontal" name="GenerateTransferCertificate"
                                    action="generate_tc.php" method="post">

                                    <div class="row" id="RecordTable">
                                        <div class="col-lg-12">
                                            <table width="100%" class="table table-striped table-bordered table-hover"
                                                id="DataTableRecords">
                                                <thead>
                                                    <tr>
                                                        <th rowspan="2">S. No</th>
                                                        <th rowspan="2">
                                                            Student&nbsp;&nbsp;<label for="AllStudent"><input
                                                                    type="checkbox" id="AllStudent" name="chkAllStudent"
                                                                    <?php echo count($Clean['StudentIDList']) == count($StudentsList) ? 'checked="checked"' : ''; ?>
                                                                    value="" /> &nbsp;All</label>
                                                        </th>
                                                        <th colspan="3" class="text-center"> Dues </th>
                                                    </tr>
                                                    <tr>
                                                        <th class="text-center">Fee</th>
                                                        <th class="text-center">Library</th>
                                                        <th class="text-center">Inventory</th>
                                                    </tr>
                                                </thead>
                                                <tbody>
                                                    <?php
                                    if (is_array($StudentsList) && count($StudentsList) > 0)
                                    {
                                        $Counter = 0;
                                        foreach ($StudentsList as $StudentID => $StudentDetails)
                                        {
                                            $DueFees = 0;
                                            $IssuedBooksAtPresentTime = 0;
                                            $DueInventoryItem = 0;
                                            
                                            $AnyDue = 0;
                                            
                                            if (array_key_exists($StudentID, $FeeDuesList))
                                            {
                                                $DueFees = $FeeDuesList[$StudentID]['TotalDue'];
                                            }
                                            
                                            $IssuedBooksAtPresentTime = BookIssue::GetAllreadyIssuedBooksToUser('Student', $StudentID);
                                            
                                            if ($DueFees > 0 || $IssuedBooksAtPresentTime > 0 || $DueInventoryItem > 0)
                                            {
                                                $AnyDue = 1;
                                            }
?>
                                                    <tr>
                                                        <td><?php echo ++$Counter; ?></td>
                                                        <td>
                                                            <label for="<?php echo $StudentID; ?>"
                                                                class="checkbox-inline"><input type="checkbox"
                                                                    id="<?php echo $StudentID; ?>"
                                                                    class="check-all-student"
                                                                    anyDue="<?php echo $AnyDue; ?>"
                                                                    name="chkStudentList[<?php echo $StudentID; ?>]"
                                                                    <?php echo (in_array($StudentID, $Clean['StudentIDList'])) ? 'checked="checked"' : ''; ?>
                                                                    value="<?php echo $StudentID; ?>" />
                                                                &nbsp;<?php echo $StudentDetails['FirstName'] .' ' . $StudentDetails['LastName'] .' ( '. $StudentDetails['RollNumber'] .' )'; ?></label>
                                                        </td>
                                                        <td
                                                            class="text-center <?php echo ($DueFees) ? 'text-danger' : '' ; ?>">
                                                            <?php echo ($DueFees) ? $DueFees : 'N/A' ; ?></td>
                                                        <td
                                                            class="text-center <?php echo ($IssuedBooksAtPresentTime) ? 'text-danger' : '' ; ?>">
                                                            <?php echo (($IssuedBooksAtPresentTime) ? $IssuedBooksAtPresentTime .' Book' : 'N/A') ; ?>
                                                        </td>
                                                        <td
                                                            class="text-center <?php echo ($DueInventoryItem) ? 'text-danger' : '' ; ?>">
                                                            <?php echo ($DueInventoryItem) ? $DueInventoryItem : 'N/A' ; ?>
                                                        </td>
                                                    </tr>
                                                    <?php
                                        }
                                    }
?>
                                                </tbody>
                                            </table>
                                        </div>
                                        <div class="form-group">
                                            <div class="col-sm-offset-2 col-lg-10">
                                                <input type="hidden" name="hdnClassID"
                                                    value="<?php echo $Clean['ClassID'];?>" />
                                                <input type="hidden" name="hdnClassSection"
                                                    value="<?php echo $Clean['ClassSectionID'];?>" />
                                                <input type="hidden" name="hdnAcademicYearID"
                                                    value="<?php echo $Clean['AcademicYearID'];?>" />
                                                <input type="hidden" name="hdnLastDateOfSession"
                                                    value="<?php echo $Clean['LastDateOfSession'];?>" />
                                                <input type="hidden" name="hdnTcIssueDate"
                                                    value="<?php echo $Clean['TcIssueDate'];?>" />
                                                <input type="hidden" name="hdnSchoolLeavingDate"
                                                    value="<?php echo $Clean['SchoolLeavingDate'];?>" />
                                                <input type="hidden" name="hdnReasonOfLeaving"
                                                    value="<?php echo $Clean['ReasonOfLeaving'];?>" />
                                                <input type="hidden" name="hdnProcess" value="1" />
                                                <button type="submit" class="btn btn-primary"><i
                                                        class="fa fa-save"></i>&nbsp;Generate TC</button>
                                            </div>
                                        </div>
                                    </div>
                                </form>
                            </div>
                            <!-- /.table-responsive -->
                        </div>
                        <!-- /.panel-body -->
                    </div>
                    <!-- /.panel -->
                </div>
                <!-- /.col-lg-12 -->
            </div>
            <?php
        }
?>
        </div>
        <!-- /#page-wrapper -->

    </div>
    <!-- /#wrapper -->
    <?php
require_once('../footer.php');
?>
    <script src="../vendor/jquery-ui/jquery-ui.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/fancybox/3.5.2/jquery.fancybox.min.js"></script>
    <script type="text/javascript">
    $(document).ready(function() {
        $(".select-date").datepicker({
            changeMonth: true,
            changeYear: true,
            dateFormat: 'dd/mm/yy'
        });

        $('#Class').change(function() {
            var ClassID = parseInt($('#Class').val());

            if (ClassID <= 0) {
                $('#ClassSection').html('<option value="0">-- Select Section --</option>');
                return;
            }

            $.post("/xhttp_calls/get_sections_by_classs.php", {
                SelectedClassID: ClassID
            }, function(data) {
                ResultArray = data.split("|*****|");

                if (ResultArray[0] == 'error') {
                    alert(ResultArray[1]);
                    return false;
                } else {
                    $('#ClassSection').html('<option value="0">-- Select Section --</option>' +
                        ResultArray[1]);
                }
            });
        });

        $('#AllStudent').change(function() {
            if ($(this).prop("checked") == true) {
                $('.check-all-student').prop('checked', true);
            } else {
                $('.check-all-student').prop('checked', false);
            }
        });

        $('.check-all-student').change(function() {

            if ($(this).attr('anyDue') == 1 && $(this).prop("checked") == true) {
                if (!confirm('Are you really want to generate TC with out No-Dues.')) {
                    $(this).prop('checked', false);
                    return false;
                } else {
                    var TotalStudent = <?php echo count($StudentsList);?>;

                    if ($('input.check-all-student:checked').length == TotalStudent) {
                        $('#AllStudent').prop('checked', true);
                    } else {
                        $('#AllStudent').prop('checked', false);
                    }
                }
            } else {
                var TotalStudent = <?php echo count($StudentsList);?>;

                if ($('input.check-all-student:checked').length == TotalStudent) {
                    $('#AllStudent').prop('checked', true);
                } else {
                    $('#AllStudent').prop('checked', false);
                }
            }
        });
    });
    </script>
</body>

</html>