<?php
require_once($_SERVER['DOCUMENT_ROOT'] . '/classes/class.db_connect.php');
error_reporting(E_ALL);

class StockReturn
{
	// CLASS MEMBERS ARE DEFINED HERE	//
	private $LastErrorCode;
	private $DBObject; // VARIABLE TO HOLD THE DB CONNECTION //
	
	private $StockReturnID;
	private $ProductID;

	private $IssueType;
	private $DepartmentID;
	private $BranchStaffID;

	private $ReturnQuantity;
	private $IssueDate;
	private $ReturnDate;

	private $CreateUserID;
	private $CreateDate;
	
	// PUBLIC METHODS START HERE	//
	public function __construct($StockReturnID = 0)
	{
		$this->DBObject = new DBConnect;
		$this->LastErrorCode = 0;
		
		if($StockReturnID != 0)
		{
			$this->StockReturnID = $StockReturnID;
			// SET THE VALUES FROM THE DATABASE.
			$this->GetStockReturnByID();
		}
		else
		{
			//SET THE DEFAULT VALUES TO LOOK ATTRIBUTES
			$this->StockReturnID = 0;
			$this->ProductID = '';

			$this->IssueType = 'Staff';
			$this->DepartmentID = 0;
			$this->BranchStaffID = 0;

			$this->ReturnQuantity = 0;
			$this->IssueDate = '0000-00-00';
			$this->ReturnDate = '0000-00-00';

			$this->CreateUserID = 0;
			$this->CreateDate = '0000-00-00 00:00:00';
		}
	}
	
	// GETTER AND SETTER FUNCTIONS START HERE	//
	public function GetStockReturnID()
	{
		return $this->StockReturnID;
	}
	
	public function GetProductID()
	{
		return $this->ProductID;
	}
	public function SetProductID($ProductID)
	{
		$this->ProductID = $ProductID;
	}

	public function GetIssueType()
	{
		return $this->IssueType;
	}
	public function SetIssueType($IssueType)
	{
		$this->IssueType = $IssueType;
	}
	
	public function GetDepartmentID()
	{
		return $this->DepartmentID;
	}
	public function SetDepartmentID($DepartmentID)
	{
		$this->DepartmentID = $DepartmentID;
	}
	
	public function GetBranchStaffID()
	{
		return $this->BranchStaffID;
	}
	public function SetBranchStaffID($BranchStaffID)
	{
		$this->BranchStaffID = $BranchStaffID;
	}

	public function GetReturnQuantity()
	{
		return $this->ReturnQuantity;
	}
	public function SetReturnQuantity($ReturnQuantity)
	{
		$this->ReturnQuantity = $ReturnQuantity;
	}

	public function GetIssueDate()
	{
		return $this->IssueDate;
	}
	public function SetIssueDate($IssueDate)
	{
		$this->IssueDate = $IssueDate;
	}	
	
	public function GetReturnDate()
	{
		return $this->ReturnDate;
	}
	public function SetReturnDate($ReturnDate)
	{
		$this->ReturnDate = $ReturnDate;
	}

	public function GetStockReturnDetails()
	{
		return $this->StockReturnDetails;
	}
	public function SetStockReturnDetails($StockReturnDetails)
	{
		$this->StockReturnDetails = $StockReturnDetails;
	}
	
	public function GetCreateUserID()
	{
		return $this->CreateUserID;
	}
	public function SetCreateUserID($CreateUserID)
	{
		$this->CreateUserID = $CreateUserID;
	}
	
	public function GetCreateDate()
	{
		return $this->CreateDate;
	}
	
	public function GetLastErrorCode()
	{
		return $this->LastErrorCode;
	}
	
	//  END OF GETTER AND SETTER FUNCTIONS 	//
	
	public function Save()
	{
		try
		{
			return $this->SaveDetails();
		}
		catch (ApplicationDBException $e)
		{
			$this->LastErrorCode = $e->getCode();
			return false;
		}
		catch (ApplicationARException $e)
		{
			$this->LastErrorCode = $e->getCode();
			return false;
		}
		catch (Exception $e)
		{
			$this->LastErrorCode = APP_ERROR_UNDEFINED_ERROR;
			return false;
		}
	}

	public function Remove()
	{
		try
		{
			$this->RemoveStockReturn();
			return true;
		}
		catch (ApplicationDBException $e)
		{
			$this->LastErrorCode = $e->getCode();
			return false;
		}
		catch (ApplicationARException $e)
		{
			$this->LastErrorCode = $e->getCode();
			return false;
		}
		catch (Exception $e)
		{
			$this->LastErrorCode = APP_ERROR_UNDEFINED_ERROR;
			return false;
		}
	}
	
	public function CheckDependencies()
	{
		try
		{
			$RSTotal = $this->DBObject->Prepare('SELECT COUNT(*) AS totalRecords FROM role_group_roles WHERE stockReturnID = :|1;');
			$RSTotal->Execute($this->StockReturnID);
	
			if ($RSTotal->FetchRow()->totalRecords > 0) 
			{
				return true;
			}
			
			return false;
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException: StockReturn::CheckDependencies(). Stack Trace: ' . $e->getTraceAsString());
			return true;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception: StockReturn::CheckDependencies(). Stack Trace: ' . $e->getTraceAsString());
			return true;
		}
	}

	public function RecordExists()
	{
		try
		{
			$QueryString = '';
			
			if ($this->StockReturnID > 0)
			{
				$QueryString = ' AND stockReturnID != ' . $this->DBObject->RealEscapeVariable($this->StockReturnID);
			}

			$RSTotal = $this->DBObject->Prepare('SELECT COUNT(*) AS totalRecords FROM aim_stock_return WHERE productID = :|1' . $QueryString . ';');
			$RSTotal->Execute($this->ProductID);
			
			if ($RSTotal->FetchRow()->totalRecords > 0)
			{
				return true;
			}
			
			return false;
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at StockReturn::RecordExists(). Stack Trace: ' . $e->getTraceAsString());
			return true;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at StockReturn::RecordExists(). Stack Trace: ' . $e->getTraceAsString());
			return true;
		}
	}

	// END OF PUBLIC METHODS	//
	
	// START OF STATIC METHODS	//
	static function GetAllStockReturn()
    { 
		$AllStockReturn = array();
		
    	try
        {	
        	$DBConnObject = new DBConnect();
        	$RSSearch = $DBConnObject->Prepare('SELECT asr.*, ap.productName, apc.productCategoryName, ad.departmentName, CONCAT(abs.firstName, " ", abs.lastName) AS branchStaffName, u.userName AS createUserName 
        											FROM aim_stock_return asr 
        											INNER JOIN aim_products ap ON asr.productID = ap.productID
        											INNER JOIN aim_product_categories apc ON ap.productCategoryID = apc.productCategoryID
        											LEFT JOIN aim_departments ad ON asr.departmentID = ad.departmentID
        											INNER JOIN asa_branch_staff abs ON asr.branchStaffID = abs.branchStaffID
													INNER JOIN users u ON asr.createUserID = u.userID 
        											ORDER BY asr.stockReturnID;');
            $RSSearch->Execute();

            if ($RSSearch->Result->num_rows <= 0)
            {
                return $AllStockReturn;
            }

            while($SearchRow = $RSSearch->FetchRow())
            {
                $AllStockReturn[$SearchRow->stockReturnID]['ProductID'] = $SearchRow->productID;
                $AllStockReturn[$SearchRow->stockReturnID]['ProductCategoryName'] = $SearchRow->productCategoryName;
                $AllStockReturn[$SearchRow->stockReturnID]['ProductName'] = $SearchRow->productName;

				$AllStockReturn[$SearchRow->stockReturnID]['IssueType'] = $SearchRow->issueType;
				$AllStockReturn[$SearchRow->stockReturnID]['DepartmentName'] = $SearchRow->departmentName;
				$AllStockReturn[$SearchRow->stockReturnID]['BranchStaffName'] = $SearchRow->branchStaffName;
				
				$AllStockReturn[$SearchRow->stockReturnID]['ReturnQuantity'] = $SearchRow->returnQuantity;
				$AllStockReturn[$SearchRow->stockReturnID]['IssueDate'] = $SearchRow->issueDate;
				$AllStockReturn[$SearchRow->stockReturnID]['ReturnDate'] = $SearchRow->returnDate;

                $AllStockReturn[$SearchRow->stockReturnID]['CreateUserID'] = $SearchRow->createUserID;
                $AllStockReturn[$SearchRow->stockReturnID]['CreateUserName'] = $SearchRow->createUserName;

                $AllStockReturn[$SearchRow->stockReturnID]['CreateDate'] = $SearchRow->createDate;
           }
            
            return $AllStockReturn;
        }
        catch (ApplicationDBException $e)
        {
            error_log('DEBUG: ApplicationDBException::StockReturn::GetAllStockReturn(). Stack Trace: '. $e->getTraceAsString());
            return $AllStockReturn;
        }
        catch (Exception $e)
        {
            error_log('DEBUG: Exception: StockReturn::GetAllStockReturn() . Stack Trace: '. $e->getTraceAsString());
            return $AllStockReturn;
        }
    }

    static function GetActiveStockReturns()
	{
		$AllStockReturn = array();
		
		try
		{
			$DBConnObject = new DBConnect();
			
			$RSSearch = $DBConnObject->Prepare('SELECT * FROM aim_stock_return WHERE issueType = 1;');
			$RSSearch->Execute();
			
			if ($RSSearch->Result->num_rows <= 0)
			{
				return $AllStockReturn;
			}
			
			while($SearchRow = $RSSearch->FetchRow())
			{
				$AllStockReturn[$SearchRow->stockReturnID] = $SearchRow->productID;
			}
			
			return $AllStockReturn;	
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at StockReturn::GetActiveStockReturns(). Stack Trace: ' . $e->getTraceAsString());
			return $AllStockReturn;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at StockReturn::GetActiveStockReturns(). Stack Trace: ' . $e->getTraceAsString());
			return $AllStockReturn;
		}		
	}

	static function GetStockQunatity($ProductID)
	{	
		$StockQuantity = 0;
		$TotalIssuedQunatityToDepartment = 0;
		$TotalQuantityIssuedByDepartment = 0;

		try
		{
			$DBConnObject = new DBConnect();
			
			$RSSearchIssuedQunatityToDepartment = $DBConnObject->Prepare('SELECT sum(returnQuantity) as totalIssuedQunatityToDepartment FROM aim_stock_return
														  					WHERE productID = :|1 AND issueType = "Department" LIMIT 1;');
			$RSSearchIssuedQunatityToDepartment->Execute($ProductID);

			$RSSearchRowIssuedQunatityToDepartment = $RSSearchIssuedQunatityToDepartment->FetchRow();

			$RSSearchQuantityIssuedByDepartment = $DBConnObject->Prepare('SELECT sum(returnQuantity) AS totalQuantityIssuedByDepartment 
																			FROM aim_department_stock_issue WHERE productID = :|1 LIMIT 1;');
			$RSSearchQuantityIssuedByDepartment->Execute($ProductID);

			$RSSearchRowQuantityIssuedByDepartment = $RSSearchQuantityIssuedByDepartment->FetchRow();

			if (count($RSSearchRowIssuedQunatityToDepartment) > 0) 
			{
				$TotalIssuedQunatityToDepartment = $RSSearchRowIssuedQunatityToDepartment->totalIssuedQunatityToDepartment;			
			}

			if (count($RSSearchRowQuantityIssuedByDepartment) > 0) 
			{
				$TotalQuantityIssuedByDepartment = $RSSearchRowQuantityIssuedByDepartment->totalQuantityIssuedByDepartment;			
			}

			$StockQuantity = $TotalIssuedQunatityToDepartment - $TotalQuantityIssuedByDepartment;
			
			return $StockQuantity;	
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at StockReturn::GetStockQunatity(). Stack Trace: ' . $e->getTraceAsString());
			return $StockQuantity;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at StockReturn::GetStockQunatity(). Stack Trace: ' . $e->getTraceAsString());
			return $StockQuantity;
		}		
	}

	static function GetProductsByDepartmentID($DepartmentID)
	{
		$AllProducts = array();
		
		try
		{
			$DBConnObject = new DBConnect();
			
			$RSSearch = $DBConnObject->Prepare('SELECT asr.productID, ap.productName 
												FROM aim_stock_return asr 
												INNER JOIN aim_products ap ON asr.productID = ap.productID
												WHERE asr.departmentID = :|1 
												AND asr.issueType = "Department";');
			$RSSearch->Execute($DepartmentID);
			
			if ($RSSearch->Result->num_rows <= 0)
			{
				return $AllProducts;
			}
			
			while($SearchRow = $RSSearch->FetchRow())
			{
				$AllProducts[$SearchRow->productID] = $SearchRow->productName;
			}
			
			return $AllProducts;	
		}
		catch (ApplicationDBException $e)
		{
			error_log('DEBUG: ApplicationDBException at StockReturn::GetProductsByDepartmentID(). Stack Trace: ' . $e->getTraceAsString());
			return $AllProducts;
		}
		catch (Exception $e)
		{
			error_log('DEBUG: Exception at StockReturn::GetProductsByDepartmentID(). Stack Trace: ' . $e->getTraceAsString());
			return $AllProducts;
		}		
	}
    
	// END OF STATIC METHODS	//
	
	// START OF PRIVATE METHODS	//
	private function SaveDetails()
	{	
		$StockQuantity = 0;

		if ($this->StockReturnID == 0)
		{
			if (is_array($this->StockReturnDetails) && !empty($this->StockReturnDetails))
			{
				//var_dump($this->StockReturnDetails);exit;
				foreach ($this->StockReturnDetails as $StockIssueID => $Details)
				{
					$RSSave = $this->DBObject->Prepare('INSERT INTO aim_stock_return (stockIssueID, productID, issueType, departmentID, branchStaffID, returnQuantity, issueDate, returnDate, createUserID, createDate)
														VALUES (:|1, :|2, :|3, :|4, :|5, :|6, :|7, :|8, :|9, NOW());');
					$RSSave->Execute($StockIssueID, $Details['ProductID'], $this->IssueType, $this->DepartmentID, $this->BranchStaffID, $Details['ReturnQuantity'], $Details['IssueDate'], $Details['ReturnDate'], $this->CreateUserID);

					$this->StockReturnID = $RSSave->LastID;

					$RSSearchReturnedQuantity = $this->DBObject->Prepare('SELECT returnedQuantity FROM aim_stock_issue WHERE stockIssueID = :|1 LIMIT 1;');
					$RSSearchReturnedQuantity->Execute($StockIssueID);

					$StockReturnedQuantity = $RSSearchReturnedQuantity->FetchRow()->issuedQuantity + $Details['ReturnQuantity'];

					$RSUpdateStockIssue = $this->DBObject->Prepare('UPDATE aim_stock_issue
																		SET	returnedQuantity = :|1
																		WHERE stockIssueID = :|2 LIMIT 1;');
					$RSUpdateStockIssue->Execute($StockReturnedQuantity, $StockIssueID);

					$RSSearchProducts = $this->DBObject->Prepare('SELECT stockQuantity FROM aim_products WHERE productID = :|1 LIMIT 1;');
					$RSSearchProducts->Execute($Details['ProductID']);

					$StockQuantity = $RSSearchProducts->FetchRow()->stockQuantity + $Details['ReturnQuantity'];

					$RSUpdateProductStock = $this->DBObject->Prepare('UPDATE aim_products
																		SET	stockQuantity = :|1
																		WHERE productID = :|2 LIMIT 1;');
					$RSUpdateProductStock->Execute($StockQuantity, $Details['ProductID']);
				}
			}
			/*$RSSave = $this->DBObject->Prepare('INSERT INTO aim_stock_return (productID, issueType, departmentID, branchStaffID, returnQuantity, issueDate, returnDate, createUserID, createDate)
														VALUES (:|1, :|2, :|3, :|4, :|5, :|6, :|7, :|8, NOW());');
			$RSSave->Execute($this->ProductID, $this->IssueType, $this->DepartmentID, $this->BranchStaffID, $this->ReturnQuantity, $this->IssueDate, $this->ReturnDate, $this->CreateUserID);

			$this->StockReturnID = $RSSave->LastID;*/

			/*$RSSearchProducts = $this->DBObject->Prepare('SELECT stockQuantity FROM aim_products WHERE productID = :|1 LIMIT 1;');
			$RSSearchProducts->Execute($this->ProductID);

			$StockQuantity = $RSSearchProducts->FetchRow()->stockQuantity - $this->ReturnQuantity;

			$RSUpdateProductStock = $this->DBObject->Prepare('UPDATE aim_products
																SET	stockQuantity = :|1
																WHERE productID = :|2 LIMIT 1;');
			$RSUpdateProductStock->Execute($StockQuantity, $this->ProductID);*/
		}
		else
		{	
			$RSSearchStockReturn = $this->DBObject->Prepare('SELECT returnQuantity, productID FROM aim_stock_return WHERE stockReturnID = :|1 LIMIT 1;');
			$RSSearchStockReturn->Execute($this->StockReturnID);

			$SearchRowStockReturn = $RSSearchStockReturn->FetchRow();

			$RSSearchProducts = $this->DBObject->Prepare('SELECT stockQuantity FROM aim_products WHERE productID = :|1 LIMIT 1;');
			$RSSearchProducts->Execute($SearchRowStockReturn->productID);

			$StockQuantity = 0; 

			$StockQuantity = $RSSearchProducts->FetchRow()->stockQuantity + $SearchRowStockReturn->returnQuantity;

			$RSUpdateProductStock = $this->DBObject->Prepare('UPDATE aim_products
																SET	stockQuantity = :|1
																WHERE productID = :|2 LIMIT 1;');
			$RSUpdateProductStock->Execute($StockQuantity, $SearchRowStockReturn->productID);


			$RSSearchProducts = $this->DBObject->Prepare('SELECT stockQuantity FROM aim_products WHERE productID = :|1 LIMIT 1;');
			$RSSearchProducts->Execute($this->ProductID);

			$StockQuantity = 0;
			$StockQuantity = $RSSearchProducts->FetchRow()->stockQuantity  + $this->ReturnQuantity;

			$RSUpdate = $this->DBObject->Prepare('UPDATE aim_stock_return
													SET	productID = :|1,
														issueType = :|2,
														departmentID = :|3,
														branchStaffID = :|4,
														returnQuantity = :|5,
														issueDate = :|6,
														returnDate = :|7
													WHERE stockReturnID = :|8 LIMIT 1;');
			$RSUpdate->Execute($this->ProductID, $this->IssueType, $this->DepartmentID, $this->BranchStaffID, $this->ReturnQuantity, $this->IssueDate, $this->ReturnDate, $this->StockReturnID);

			$RSUpdateProductStock = $this->DBObject->Prepare('UPDATE aim_products
																SET	stockQuantity = :|1
																WHERE productID = :|2 LIMIT 1;');
			$RSUpdateProductStock->Execute($StockQuantity, $this->ProductID);

		}
		
		return true;
	}

	private function RemoveStockReturn()
	{
		if(!isset($this->StockReturnID)) 
		{
    		throw new ApplicationARException('', APP_AR_ERROR_DELETE_WITHOUT_ID);
		}
		
		$RSDeleteStockReturn = $this->DBObject->Prepare('DELETE FROM aim_stock_return WHERE stockReturnID = :|1 LIMIT 1;');
		$RSDeleteStockReturn->Execute($this->StockReturnID);				
	}
	
	private function GetStockReturnByID()
	{
		$RSStockReturn = $this->DBObject->Prepare('SELECT * FROM aim_stock_return WHERE stockReturnID = :|1 LIMIT 1;');
		$RSStockReturn->Execute($this->StockReturnID);
		
		$StockReturnRow = $RSStockReturn->FetchRow();
		
		$this->SetAttributesFromDB($StockReturnRow);				
	}
	
	private function SetAttributesFromDB($StockReturnRow)
	{
		$this->StockReturnID = $StockReturnRow->stockReturnID;
		$this->ProductID = $StockReturnRow->productID;

		$this->IssueType = $StockReturnRow->issueType;
		$this->DepartmentID = $StockReturnRow->departmentID;
		$this->BranchStaffID = $StockReturnRow->branchStaffID;

		$this->ReturnQuantity = $StockReturnRow->returnQuantity;
		$this->IssueDate = $StockReturnRow->issueDate;
		$this->ReturnDate = $StockReturnRow->issueDate;

		$this->CreateUserID = $StockReturnRow->createUserID;
		$this->CreateDate = $StockReturnRow->createDate;
	}	
}
?>