<?php

require_once("../classes/class.users.php");
require_once("../classes/class.validation.php");
require_once("../classes/class.authentication.php");

require_once('../classes/school_administration/class.academic_years.php');
require_once("../classes/school_administration/class.students.php");
require_once("../classes/school_administration/class.parent_details.php");
require_once("../classes/school_administration/class.student_details.php");

require_once("../classes/school_administration/class.classes.php");
require_once("../classes/school_administration/class.section_master.php");
require_once("../classes/school_administration/class.class_sections.php");
require_once("../classes/academic_supervision/class.student_Cc_details.php");

require_once("../classes/class.date_processing.php");
require_once("../includes/global_defaults.inc.php");

try {
    $AuthObject = new ApplicationAuthentication;
    $LoggedUser = new User(0, $AuthObject->CheckValidUser());
}

// THIS CATCH BLOCK BUBBLES THE EXCEPTION TO THE BUILT IN 'Exception' CLASS IF THERE ARE ANY UNCAUGHT ERRORS //
catch (ApplicationAuthException $e) {
    echo 'error|*****|Unknown error, please try again.';
    exit;
} catch (Exception $e) {
    echo 'error|*****|Unknown error, please try again.';
    exit;
}

if ($LoggedUser->HasPermissionForTask(TASK_EDIT_STUDENT) !== true) {
    header('location:/admin/unauthorized_login_admin.php');
    exit;
}

$HasErrors = false;

$StudentID = '';
$StudentName = '';
$ParentsName = '';
$Class = '';
$Address = '';
$AdmissionDate = '';
$AcademicYear = '';

if (isset($_POST['id'])) {
    $StudentID = (int)($_POST['id']);
}
if (isset($_POST['studentName'])) {
    $StudentName = strip_tags(trim($_POST['studentName']));
}
if (isset($_POST['parentsName'])) {
    $ParentsName = strip_tags(trim($_POST['parentsName']));
}
if (isset($_POST['address'])) {
    $Address = strip_tags(trim($_POST['address']));
}
if (isset($_POST['class'])) {
    $Class = strip_tags(trim($_POST['class']));
}

if (isset($_POST['admissionDate'])) {
    $AdmissionDate = $_POST['admissionDate'];
}

if (isset($_POST['academicYear'])) {
    $AcademicYear = strip_tags(trim($_POST['academicYear']));
}

$RecordValidator = new Validator();

if (!$RecordValidator->ValidateInteger($StudentID, '', 3, 250)) {
    echo 'error|*****|Please enter a Student Name between 3 and 250 characters.';
    exit;
}

if (!$RecordValidator->ValidateStrings($StudentName, '', 3, 250)) {
    echo 'error|*****|Please enter a Student Name between 3 and 250 characters.';
    exit;
}

if (!$RecordValidator->ValidateStrings($ParentsName, '', 3, 250)) {
    echo 'error|*****|Please enter a Parents Name between 3 and 250 characters.';
    exit;
}

if (!$RecordValidator->ValidateStrings($Class, '', 1, 2)) {
    echo 'error|*****|Please enter a Class between 1 and 2 characters.';
    exit;
}

if (!$RecordValidator->ValidateStrings($Address, '', 2, 250)) {
    echo 'error|*****|Please enter a Address between 2 and 250 characters.';
    exit;
}

if (!StudentCcDetail::UpdateStudentCCDetails($StudentID, $StudentName,  $ParentsName,  $Class,  $Address,  $AdmissionDate, $AcademicYear)) {
    echo 'error|*****|Record not saved, some problem occurred.';
    exit;
}

echo 'success|*****|Record Update successfully.';
exit;
